==> gnome-vfsmm-1.3.1.tar.gz: gnome-vfsmm-1.3.1/libgnomevfs/libgnomevfsmm.h <==
/* $Id: libgnomevfsmm.h,v 1.3 2003/03/29 10:11:10 murrayc Exp $ */
/* libgnomevfsmm - a C++ wrapper for libgda
 *
 * Copyright 1999-2003 Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LIBGNOMEVFSMM_H
#define LIBGNOMEVFSMM_H

//extern "C" {
//#include <gtk/gtk.h>
//}

/* libgnomevfsmm version.  */
extern const int libgnomevfsmm_major_version;
extern const int libgnomevfsmm_minor_version;
extern const int libgnomevfsmm_micro_version;

#include <gtkmm.h>

#include <libgnomevfsmm/init.h>
#include <libgnomevfsmm/application-registry.h>
#include <libgnomevfsmm/enums.h>
#include <libgnomevfsmm/directory-handle.h>
#include <libgnomevfsmm/handle.h>
#include <libgnomevfsmm/file-info.h>
#include <libgnomevfsmm/mime-monitor.h>
#include <libgnomevfsmm/uri.h>

#endif /* #ifndef LIBGNOMEVFSMM_H */

==> gnome-vfsmm-2.5.0.tar.gz: gnome-vfsmm-2.5.0/libgnomevfs/libgnomevfsmm.h <==
/* $Id: libgnomevfsmm.h,v 1.7 2003/07/21 20:54:04 mxpxpod Exp $ */
/* libgnomevfsmm - a C++ wrapper for libgda
 *
 * Copyright 1999-2003 Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LIBGNOMEVFSMM_H
#define LIBGNOMEVFSMM_H

/* libgnomevfsmm version.  */
extern const int libgnomevfsmm_major_version;
extern const int libgnomevfsmm_minor_version;
extern const int libgnomevfsmm_micro_version;

#include <glibmm.h>

#include <libgnomevfsmm/init.h>
#include <libgnomevfsmm/application-registry.h>
#include <libgnomevfsmm/enums.h>
#include <libgnomevfsmm/types.h>
#include <libgnomevfsmm/directory-handle.h>
#include <libgnomevfsmm/handle.h>
#include <libgnomevfsmm/file-info.h>
#include <libgnomevfsmm/mime-application.h>
#include <libgnomevfsmm/mime-action.h>
#include <libgnomevfsmm/mime-handlers.h>
#include <libgnomevfsmm/mime-monitor.h>
#include <libgnomevfsmm/uri.h>
#include <libgnomevfsmm/monitor-handle.h>
#include <libgnomevfsmm/transfer-progress.h>
#include <libgnomevfsmm/transfer.h>

#endif /* #ifndef LIBGNOMEVFSMM_H */
